@@ -4,8 +4,8 @@
 #
 # GetLive - perl script to get mail from hotmail (live) mailboxes.
 #
-# $Id: GetLive.pl,v 1.52 2010/02/18 22:04:12 jdla Exp $
-# $Name:  $
+# $Id: GetLive.pl,v 1.55 2010/03/13 15:22:39 jdla Exp $
+# $Name: Release_0_59 $
 #
 # Copyright (C) 2007-2009 Jos De Laender <jos.de_laender@pandora.be>
 #
@@ -14,7 +14,7 @@
 #   Copyright (C) 2000-2003 Peter Hawkins <peterhawkins@ozemail.com.au>
 #   Copyright (C) 2005 Jon Phillips <jon@rejon.org>
 #   Copyright (C) 2005 Michael Ziegler.
-#   Copyright (C) 2005-2006 Jos De Laender <jos.de_laender@pandora.be>
+#   Copyright (C) 2005-2010 Jos De Laender <jos.de_laender@pandora.be>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@ eval "use encoding(\":locale\");";
 ########################################################################################################################
 
 my $ProgramName = "GetLive";
-my $Revision    = '$Revision: 1.52 $';		# Meant for RCS.
+my $Revision    = '$Revision: 1.55 $';		# Meant for RCS.
 
 # Constants of configuration.
 my $Proxy                   = "";
@@ -94,7 +94,7 @@ my $AllowUncompletePreTag = 1;
 my $CorrectDarrenQuirk = 1;
 
 # Files in a temporary directory.
-my $TmpDir             = File::Spec->tmpdir() . "/$ProgramName.$$";
+my $TmpDir             = File::Spec->tmpdir() . "/$ProgramName.$$.$^T";
 my $TmpCurlHeadersFile = "$TmpDir/Headers";
 my $TmpCookiesFile     = "$TmpDir/Cookies";
 my $TmpFormDataFile    = "$TmpDir/Form";
@@ -140,7 +140,8 @@ my $TrashFolderId		  = "";
 
 $SIG{INT} = $SIG{TERM} = $SIG{__DIE__} = sub {
   my($Text) = @_;
-  print STDERR "$ProgramName died with message: '$Text'.";
+  chomp($Text);
+  print STDERR "$ProgramName died with message: '$Text'.\n";
   CleanTempFiles();
   exit(1);
 };
@@ -197,8 +198,8 @@ sub DisplayIntroText(%) {
   	"$ProgramName comes with ABSOLUTELY NO WARRANTY.\n".
   	"This is free software, and you are welcome to redistribute it\n".
   	"under certain conditions; see the file License for details.\n".
-  	'$Name:  $' . "\n".
-  	'$Id: GetLive.pl,v 1.52 2010/02/18 22:04:12 jdla Exp $' . "\n".
+  	'$Name: Release_0_59 $' . "\n".
+  	'$Id: GetLive.pl,v 1.55 2010/03/13 15:22:39 jdla Exp $' . "\n".
     "Running at ".localtime(time)." for user $Login.\n";
   Display($Text,%Args);
 }
@@ -353,8 +354,8 @@ sub ParseConfig {
     Display("Delete must be 'No' when MoveToFolder is also specified in the configuration file.\n",stderr=>1);
     DisplayUsageAndExit(); 
   }
-  if ($Mode !~ m/^(200809|200810|200902|200909|201002)$/i) {
-    Display("Mode must be oneof 200809,200810,200902,200909,201002 as argument in the configuration file.\n",stderr=>1);
+  if ($Mode !~ m/^(200809|200810|200902|200909|201002|201003)$/i) {
+    Display("Mode must be oneof 200809,200810,200902,200909,201002,201003 as argument in the configuration file.\n",stderr=>1);
     DisplayUsageAndExit(); 
   }
 }
@@ -565,20 +566,26 @@ sub Login() {
     Display("Found base href to be '$BaseHref'.\n",MinVerbosity => 10);
   }
 
+  my @JavaScriptHrefs;
   my $JavaScriptHref = "";
-  if ($LoginPageAsString =~ m/<script\s+type=\"text\/javascript\"\s+src=\"([^\"]+)\"/ ) {
+  while ($LoginPageAsString =~ m/<script\s+type=\"text\/javascript\"\s+src=\"([^\"]+)\"/g ) {
     $JavaScriptHref = $1;
+    push @JavaScriptHrefs,$JavaScriptHref;
     Display("Found javascript href to be '$JavaScriptHref'.\n",MinVerbosity => 10);
   }
   
   die "Expected javascript href at this stage." unless $JavaScriptHref;
  
-  Display("Fetching the JS href.\n",MinVerbosity => 10);
-  my ($JSPageAsString,$JSGetPageUrl) = GetPage(Url => "${BaseHref}$JavaScriptHref",FollowForward => 1);
+  foreach my $Ref (@JavaScriptHrefs) {
+    Display("Fetching the JS href.\n",MinVerbosity => 10);
+    if ($Ref !~ m/^http:\/\//) {
+      $Ref = $BaseHref . $Ref;
+    }
+    my ($JSPageAsString,$JSGetPageUrl) = GetPage(Url => "$Ref",FollowForward => 1);
 
-  # Append the JS stuff into our page.
-
-  $LoginPageAsString .= $JSPageAsString;
+    # Append the JS stuff into our page.
+    $LoginPageAsString .= $JSPageAsString;
+  }
 
   # We would look to :
   #
@@ -598,26 +605,49 @@ sub Login() {
   # Assume also g_sRBlob -->srf_sRBlob
 
 
-  # FormStart as in herebove described analysis.
-  if ($LoginPageAsString !~ m/function FormStart\(\)\s*\{([^\}]+)\}/i) {
-    die "Page doesn't contain FormStart as expected.";
+  my $FormStart;
+  if ($Mode =~ m/201003/) {
+    if ($LoginPageAsString !~ m/function\s+_d5\(a\)\s*\{([^\}]+)\}/i) {
+      die "Page doesn't contain _d5 as expected.";
+    }
+    $FormStart = $1;
+  } else {
+    # FormStart as in herebove described analysis.
+    if ($LoginPageAsString !~ m/function FormStart\(\)\s*\{([^\}]+)\}/i) {
+      die "Page doesn't contain FormStart as expected.";
+    }
+    $FormStart = $1;
   }
-  my $FormStart = $1;
   Display("FormStart detected as '$FormStart'.\n", MinVerbosity => 10 );
 
   # Hidden fields as described above.
   my %Fields = ();
-  while ($FormStart =~ m/s\+=WL_HiddenField\(\"([^\"]+)\",[^,]+,([^\)]+)\)/gc) {
-    my $Key = $1;
-    my $Val = $2;
-    if ($Val =~ m/\"([^\"]+)\"/) {
-      $Val = $1;
+  if ($Mode =~ m/201003/) {
+    while ($FormStart =~ m/a\.setPostParam\(\"([^\"]+)\",[^,]+,([^\)]+)\)/gc) {
+      my $Key = $1;
+      my $Val = $2;
+      if ($Val =~ m/\"([^\"]+)\"/) {
+        $Val = $1;
+      }
+      if ($Val eq "null") {
+        $Val = "";
+      }
+      $Fields{$Key} = $Val;
+      Display("Detected setPostParam : $Key->$Val\n", MinVerbosity => 10);
     }
-    if ($Val eq "null") {
-      $Val = "";
+  } else {
+    while ($FormStart =~ m/s\+=WL_HiddenField\(\"([^\"]+)\",[^,]+,([^\)]+)\)/gc) {
+      my $Key = $1;
+      my $Val = $2;
+      if ($Val =~ m/\"([^\"]+)\"/) {
+        $Val = $1;
+      }
+      if ($Val eq "null") {
+        $Val = "";
+      }
+      $Fields{$Key} = $Val;
+      Display("Detected HiddenField : $Key->$Val\n", MinVerbosity => 10);
     }
-    $Fields{$Key} = $Val;
-    Display("Detected HiddenField : $Key->$Val\n", MinVerbosity => 10);
   }
 
 REENTRY_DARREN_QUIRK:
@@ -754,8 +784,8 @@ LABEL_20090214:
  
   die "Could not log in. Maybe structure has changes or was not foreseen." unless $LoggedIn;
 
-  if ($Mode =~ m/201002/) {
-    $BaseUrl .= "mail/";
+  if ($Mode =~ m/(201002|201003)/) {
+    $BaseUrl .= "mail/" if ($BaseUrl !~ m/mail\/$/);
     if ($LoginPageAsString =~ m/ManageFoldersLight\.aspx\?(n=\d+)/) {
       $NParameter = $1;
     }
@@ -823,7 +853,7 @@ sub MoveToFolder($$$) {
   my $MT = FindCookie("mt");
   my $Url = "";
   my $PostData = "";
-  if ($Mode =~ m/(200909|201002)/) {
+  if ($Mode =~ m/(200909|201002|201003)/) {
     $Url = "${BaseUrl}$RequestHandler?cnmn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox.MoveMessagesToFolder&". 
   	       "a=$SessionId&".
   		   "au=$AuthUser";
@@ -895,7 +925,7 @@ sub MarkRead($$) {
   my $Url = "";
   my $PostData = "";
   my $MT = FindCookie("mt");
-  if ($Mode =~ m/(200909|201002)/) {
+  if ($Mode =~ m/(200909|201002|201003)/) {
     $Url = "${BaseUrl}$RequestHandler?cnmn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox.MarkMessagesReadState&".
   	       "a=$SessionId&".
   		   "au=$AuthUser";
@@ -1034,7 +1064,7 @@ sub GetMessagesFromFolder($) {
     my $MT  = FindCookie("mt");
     if ($RequestHandler) {
       my $Url;
-      if ($Mode =~ m/(200909|201002)/) {
+      if ($Mode =~ m/(200909|201002|201003)/) {
         $Url = "${BaseUrl}$RequestHandler?cnmn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox.GetInboxData&". 
       	       "a=$SessionId&".
       	       "au=$AuthUser&".
@@ -1096,7 +1126,7 @@ sub GetMessagesFromFolder($) {
                       "v=1".
                       "&".
                       "mt=$MT";
-      } elsif ($Mode =~ m/(200909|201002)/ && $Page == 1) {
+      } elsif ($Mode =~ m/(200909|201002|201003)/ && $Page == 1) {
         $PostData = "cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox".
                     "&".
                     "mn=GetInboxData".
@@ -1109,7 +1139,7 @@ sub GetMessagesFromFolder($) {
                       "v=1".
                       "&".
                     "mt=$MT";
-      } elsif ($Mode =~ m/(200909|201002)/) {
+      } elsif ($Mode =~ m/(200909|201002|201003)/) {
         $PostData = "cn=Microsoft.Msn.Hotmail.Ui.Fpp.MailBox".
                     "&".
                     "mn=GetInboxData".
@@ -1158,7 +1188,7 @@ sub GetMessagesFromFolder($) {
     if ($Mode =~ m/200809/ && $PageAsString !~ m/<table class=\"d?ItemListContentTable[^>]*>(.*?)<\/table/si) {
       die "Could not correctly parse the messages table.";
     }
-    if ($Mode =~ m/(200810|200902|200909|201002)/ && $PageAsString !~ m/<table class=\"d?InboxTable[^>]*>(.*?)<\/table/si) {
+    if ($Mode =~ m/(200810|200902|200909|201002|201003)/ && $PageAsString !~ m/<table class=\"d?InboxTable[^>]*>(.*?)<\/table/si) {
       die "Could not correctly parse the messages table.";
     }
     my $MessagesArea = $1;
@@ -1191,7 +1221,7 @@ sub GetMessagesFromFolder($) {
       # Goto column containing from info.(to get the from)
       my $TdLine = "";
       my $Column = 5;
-      if ($Mode =~ m/(200810|200902|200909|201002)/) { $Column = 4; }
+      if ($Mode =~ m/(200810|200902|200909|201002|201003)/) { $Column = 4; }
       for (my $Idx=0;$Idx<($Column-1);$Idx++) {
         $MessagesArea =~ m/<td(.*?)>(.*?)<\/td\s*>/i;
         $MessagesArea = $';
@@ -1203,7 +1233,7 @@ sub GetMessagesFromFolder($) {
           die "Parse error for 'from'.";
         }
         $From = HtmlUnescape($3);
-      } elsif ($Mode =~ /(200810|200902|200909|201002)/ ) {
+      } elsif ($Mode =~ /(200810|200902|200909|201002|201003)/ ) {
         if ($TdLine !~ m/(<[^>]+>)?(.*?)<[^>]+>/si) {
           die "Parse error for 'from'.";
         }
@@ -1221,7 +1251,7 @@ sub GetMessagesFromFolder($) {
         $MessagesArea =~ m/<td class=\"SubjectCol\">(.*?)<\/td\s*>/i;
         $MessagesArea = $';
         $TdLine = $1;
-      } elsif ($Mode =~ /(200902|200909|201002)/) {
+      } elsif ($Mode =~ /(200902|200909|201002|201003)/) {
         $MessagesArea =~ m/<td class=\"Sbj\">(.*?)<\/td\s*>/i;
         $MessagesArea = $';
         $TdLine = $1;
@@ -1259,7 +1289,7 @@ sub GetMessagesFromFolder($) {
           $NextPageAd = $1;
         }
         die "Could not find an expected next page href. Probably page structure changed." unless $NextPageAd;
-      } elsif ($Mode =~ m/(200810|200902|200909|201002)/) {
+      } elsif ($Mode =~ m/(200810|200902|200909|201002|201003)/) {
         if ($PageAsString =~ 
           m/<li([^>]*)>\s*<a href=\"([^\"]+)\"[^>]*><img class=\"PageNavigationNext\".*?><\/a>/si) {
           $NextPageAd = $1;
@@ -1443,7 +1473,7 @@ for (my $FolderIdx=0;$FolderIdx<$NrFolders;$FolderIdx++) {
   next if (scalar keys %FoldersToProcess && not exists $FoldersToProcess{lc $FolderNames[$FolderIdx]});
   next if ( ($SkipTrash =~ m/^Yes$/i) && ($FolderIds[$FolderIdx] eq $TrashFolderId) );
   # JDLA hack. Drafts folder does not work, also not in real. Assuming 000-...-4 is the draft folder.
-  next if ( ($Mode =~ m/(200810|200902|200909|201002)/) && ($FolderIds[$FolderIdx] =~ m/^(0|-)*4$/));
+  next if ( ($Mode =~ m/(200810|200902|200909|201002|201003)/) && ($FolderIds[$FolderIdx] =~ m/^(0|-)*4$/));
   Display("\nProcessing folder $FolderNames[$FolderIdx].\n",MinVerbosity => 1);
   GetMessagesFromFolder($FolderIdx);
   Display("$NrMessagesDetected/$NrMessagesUnread Messages/Unread.\n",MinVerbosity => 1);
@@ -1457,6 +1487,18 @@ exit(0);
 ########################################################################################################################
 # 
 # $Log: GetLive.pl,v $
+# Revision 1.55  2010/03/13 15:22:39  jdla
+#
+# *) Some code cleanup for Release_0_59
+#
+# Revision 1.54  2010/03/12 14:24:05  jdla
+#
+# *) Yet another MS change. Use Mode=201003 if hit by it.
+#
+# Revision 1.53  2010/02/24 19:21:15  jdla
+#
+# *) 2 Minor changes suggested by Sebastian Lange
+#
 # Revision 1.52  2010/02/18 22:04:12  jdla
 #
 # *) It seems MS is changing again. Mode 201002 added therefore.
